searchNodes=[{"doc":"Runtime interface to manipulate on-disk secrets.","ref":"SecretVault.html","title":"SecretVault","type":"module"},{"doc":"Remove secret name from the vault specified by the config from disk. Example: iex&gt; config = SecretVault.Config . test_config iex&gt; SecretVault . put ( config , &quot;db_password&quot; , &quot;super_secret_password&quot; ) iex&gt; SecretVault . delete ( config , &quot;db_password&quot; ) iex&gt; SecretVault . fetch ( config , &quot;db_password&quot; ) { :error , { :secret_not_found , &quot;db_password&quot; , &quot;test&quot; } }","ref":"SecretVault.html#delete/2","title":"SecretVault.delete/2","type":"function"},{"doc":"Tells whether the secret name exists. Example: iex&gt; config = SecretVault.Config . test_config iex&gt; SecretVault . put ( config , &quot;db_password&quot; , &quot;super_secret_password&quot; ) iex&gt; SecretVault . exists? ( config , &quot;db_password&quot; ) true iex&gt; SecretVault . exists? ( config , &quot;non_present_password&quot; ) false","ref":"SecretVault.html#exists?/2","title":"SecretVault.exists?/2","type":"function"},{"doc":"Fetch a clear text value of the secret name using the config . Reads a data from disk storage, decrypts it, and returns the result of an operation in an &quot;either&quot; manner. Example: iex&gt; config = SecretVault.Config . test_config iex&gt; SecretVault . put ( config , &quot;db_password&quot; , &quot;super_secret_password&quot; ) iex&gt; SecretVault . fetch ( config , &quot;db_password&quot; ) { :ok , &quot;super_secret_password&quot; } iex&gt; SecretVault . fetch ( config , &quot;non_present_password&quot; ) { :error , { :secret_not_found , &quot;non_present_password&quot; , &quot;test&quot; } }","ref":"SecretVault.html#fetch/2","title":"SecretVault.fetch/2","type":"function"},{"doc":"Fetch a clear text value of the secret name using the config . Fetch a clear text value of the secret name using the config . Reads a data from disk storage, decrypts it, and returns the decrypted data or raises if no secret with the name found. Example: iex&gt; config = SecretVault.Config . test_config iex&gt; SecretVault . put ( config , &quot;db_password&quot; , &quot;super_secret_password&quot; ) iex&gt; SecretVault . fetch! ( config , &quot;db_password&quot; ) &quot;super_secret_password&quot;","ref":"SecretVault.html#fetch!/2","title":"SecretVault.fetch!/2","type":"function"},{"doc":"Asynchronously fetches all secrets from the vault specified by the config from disk. This function returns a map or error in &quot;either&quot; manner. Example: iex&gt; config = SecretVault.Config . test_config iex&gt; SecretVault . put ( config , &quot;db_password&quot; , &quot;super_secret_password&quot; ) iex&gt; SecretVault . put ( config , &quot;admin_password&quot; , &quot;another_password&quot; ) iex&gt; SecretVault . fetch_all ( config ) { :ok , %{ &quot;db_password&quot; =&gt; &quot;super_secret_password&quot; , &quot;admin_password&quot; =&gt; &quot;another_password&quot; } }","ref":"SecretVault.html#fetch_all/1","title":"SecretVault.fetch_all/1","type":"function"},{"doc":"Get a clear text value of the secret name using the config . Reads a data from disk storage, decrypts it, and returns the default if secret was not found. Example: iex&gt; config = SecretVault.Config . test_config iex&gt; SecretVault . put ( config , &quot;db_password&quot; , &quot;super_secret_password&quot; ) iex&gt; SecretVault . get ( config , &quot;db_password&quot; ) &quot;super_secret_password&quot; iex&gt; SecretVault . get ( config , &quot;non_present_password&quot; ) &quot;&quot;","ref":"SecretVault.html#get/3","title":"SecretVault.get/3","type":"function"},{"doc":"Show all secrets' names available. It reads secrets from directory specified by config and retruns a list of names with no particular order. Example: iex&gt; config = SecretVault.Config . test_config iex&gt; SecretVault . put ( config , &quot;db_password&quot; , &quot;super_secret_password&quot; ) iex&gt; SecretVault . put ( config , &quot;admin_password&quot; , &quot;another_password&quot; ) iex&gt; { :ok , names } = SecretVault . list ( config ) iex&gt; &quot;db_password&quot; in names true iex&gt; &quot;admin_password&quot; in names true","ref":"SecretVault.html#list/1","title":"SecretVault.list/1","type":"function"},{"doc":"Put data as a value of the secret name using the config . This function writes encrypted data to the disk, therefore use this with caution. If you want to write data in runtime, it is recommended to create singleton process to perform mutating operations Example: iex&gt; config = SecretVault.Config . test_config iex&gt; SecretVault . put ( config , &quot;db_password&quot; , &quot;super_secret_password&quot; ) iex&gt; SecretVault . get ( config , &quot;db_password&quot; ) &quot;super_secret_password&quot;","ref":"SecretVault.html#put/3","title":"SecretVault.put/3","type":"function"},{"doc":"Like SecretVault.runtime_secret!/3 but accepts default value when secret is not found as the third parameter.","ref":"SecretVault.html#runtime_secret/4","title":"SecretVault.runtime_secret/4","type":"macro"},{"doc":"Helper macro for getting secrets in config/runtime.exs file. Example # in `config/runtime.exs` import Config import SecretVault , only : [ runtime_secret! : 2 ] config :my_app , MyApp.Repo , password : runtime_secret! ( :my_app , &quot;database_password&quot; ) For a list of available options, see SecretVault.Config.config_option/0","ref":"SecretVault.html#runtime_secret!/3","title":"SecretVault.runtime_secret!/3","type":"macro"},{"doc":"Name of a secret","ref":"SecretVault.html#t:name/0","title":"SecretVault.name/0","type":"type"},{"doc":":unknown_prefix means that directory with secrets is not present on disk :secret_not_found means that secret file itself is not present","ref":"SecretVault.html#t:reason/0","title":"SecretVault.reason/0","type":"type"},{"doc":"Binary value you want to store in secret. To store arbitary structures, try usings :erlang.term_to_binary/2","ref":"SecretVault.html#t:value/0","title":"SecretVault.value/0","type":"type"},{"doc":"Configuration for a SecretVault vault. This configuration defines ciphers, their options, holds simmetric encryption key and path to the vault.","ref":"SecretVault.Config.html","title":"SecretVault.Config","type":"module"},{"doc":"Return list of options available for config.","ref":"SecretVault.Config.html#available_options/0","title":"SecretVault.Config.available_options/0","type":"function"},{"doc":"Same as fetch_from_env/3 , but passes env authomatically. Fetch config from the application configuration (e.g. in confix.exs ). otp_app is the current OTP application name. prefix must be one of the configured prefixes.","ref":"SecretVault.Config.html#fetch_from_current_env/3","title":"SecretVault.Config.fetch_from_current_env/3","type":"function"},{"doc":"Creates a struct that keeps configuration data for the storage. app_name is an OTP application name for the app you want to keep secrets for.","ref":"SecretVault.Config.html#new/2","title":"SecretVault.Config.new/2","type":"function"},{"doc":"A module implementing SecretVault.EncryptionProvider behaviour.","ref":"SecretVault.Config.html#t:cipher/0","title":"SecretVault.Config.cipher/0","type":"type"},{"doc":"Options for specified cipher.","ref":"SecretVault.Config.html#t:cipher_opts/0","title":"SecretVault.Config.cipher_opts/0","type":"type"},{"doc":"Options to set for a config.","ref":"SecretVault.Config.html#t:config_option/0","title":"SecretVault.Config.config_option/0","type":"type"},{"doc":"Simmetric key for cipher","ref":"SecretVault.Config.html#t:key/0","title":"SecretVault.Config.key/0","type":"type"},{"doc":"A module implementing SecretVault.KeyDerivation","ref":"SecretVault.Config.html#t:key_derivation/0","title":"SecretVault.Config.key_derivation/0","type":"type"},{"doc":"Options for specified key derivation function.","ref":"SecretVault.Config.html#t:key_derivation_opts/0","title":"SecretVault.Config.key_derivation_opts/0","type":"type"},{"doc":"Plain string password","ref":"SecretVault.Config.html#t:password/0","title":"SecretVault.Config.password/0","type":"type"},{"doc":"Path prefix for your secrets in priv directory. It's usefull when you want to have more than one secret storage. Defaults to secrets .","ref":"SecretVault.Config.html#t:prefix/0","title":"SecretVault.Config.prefix/0","type":"type"},{"doc":"Priv path. Use it only when you wan't to specify it by hands.","ref":"SecretVault.Config.html#t:priv_path/0","title":"SecretVault.Config.priv_path/0","type":"type"},{"doc":"","ref":"SecretVault.Config.html#t:t/0","title":"SecretVault.Config.t/0","type":"type"},{"doc":"Module with helpers to store secrets in various storages. Transform function All functions in this module accept an optional argument: transform which is a function to transform secret values. This may be helpful if your storage doesn't support string keys (or may be you don't want to deal with them) or if you just want to transform the data somehow.","ref":"SecretVault.Storage.html","title":"SecretVault.Storage","type":"module"},{"doc":"Stores secrets in a Application env using Application.put_env/4 . Stored secrets can be accessed with Application.fetch_env!(application_name, :secret_storage)[name] . Example iex&gt; config = SecretVault.Config . test_config ( ) iex&gt; SecretVault . put ( config , &quot;name&quot; , &quot;value&quot; ) iex&gt; to_application_env ( config , :secret_vault ) iex&gt; Application . fetch_env! ( :secret_vault , :secret_storage ) [ &quot;name&quot; ] &quot;value&quot;","ref":"SecretVault.Storage.html#to_application_env/4","title":"SecretVault.Storage.to_application_env/4","type":"function"},{"doc":"Stores secrets in a :ets table using :ets.insert . Stored secrets can be accessed with :ets.lookup(table, name) or other :ets functions. Example iex&gt; config = SecretVault.Config . test_config ( ) iex&gt; SecretVault . put ( config , &quot;name&quot; , &quot;value&quot; ) iex&gt; table = :ets . new ( :example_table , [ :set , :protected ] ) iex&gt; to_ets ( config , table ) iex&gt; :ets . lookup ( table , &quot;name&quot; ) [ { &quot;name&quot; , &quot;value&quot; } ]","ref":"SecretVault.Storage.html#to_ets/3","title":"SecretVault.Storage.to_ets/3","type":"function"},{"doc":"Stores secrets in a :persistent_term . Stored secrets can be accessed with :persistent_term.get(name) Example iex&gt; config = SecretVault.Config . test_config ( ) iex&gt; SecretVault . put ( config , &quot;name&quot; , &quot;value&quot; ) iex&gt; to_persistent_term ( config ) iex&gt; :persistent_term . get ( &quot;name&quot; ) &quot;value&quot;","ref":"SecretVault.Storage.html#to_persistent_term/2","title":"SecretVault.Storage.to_persistent_term/2","type":"function"},{"doc":"Stores secrets in a Application env using Process.put/2 . Stored secrets can be accessed with Process.get(name) Example iex&gt; config = SecretVault.Config . test_config ( ) iex&gt; SecretVault . put ( config , &quot;name&quot; , &quot;value&quot; ) iex&gt; to_proccess_dictionary ( config ) iex&gt; Process . get ( &quot;name&quot; ) &quot;value&quot;","ref":"SecretVault.Storage.html#to_proccess_dictionary/2","title":"SecretVault.Storage.to_proccess_dictionary/2","type":"function"},{"doc":"A function that transforms values fetched from the secret vault.","ref":"SecretVault.Storage.html#t:transform_function/0","title":"SecretVault.Storage.transform_function/0","type":"type"},{"doc":"Performs audit of passwords, detect duplicates and weak passwords. Exits with exit code 1 if at least one check fails. Usage $ mix scr.audit Check options --no-similarity - to disable password similarity check --digits - to enforce passwords having at least one digit --uppercase - to enforce uppercase letters in password --mix-length=N - to enforce minimul length requirement --no-plaintext - to disable checking for unencrypted passwords Config override You can override config options by providing command line arguments. :cipher - specify a cipher module to use; :priv_path - path to priv directory; :prefix - prefix to use (defaults to default ); :password - use a password that's different from the one that's configured.","ref":"Mix.Tasks.Scr.Audit.html","title":"Mix.Tasks.Scr.Audit","type":"task"},{"doc":"Callback implementation for Mix.Task.run/1 .","ref":"Mix.Tasks.Scr.Audit.html#run/1","title":"Mix.Tasks.Scr.Audit.run/1","type":"function"},{"doc":"Creates a new secret in the specified environment and under the specified name using your preffered editor. It uses configuration of the current application to retrieve the keys and other options. Usage $ mix scr.create prod database_url Config override You can override config options by providing command line arguments. :cipher - specify a cipher module to use; :priv_path - path to priv directory; :prefix - prefix to use (defaults to default ); :password - use a password that's different from the one that's configured.","ref":"Mix.Tasks.Scr.Create.html","title":"Mix.Tasks.Scr.Create","type":"task"},{"doc":"Creates a new secret in the specified environment and under the specified name using your preffered editor. It uses configuration of the current application to retrieve the keys and so on. Usage $ mix scr.edit prod database_url Config override You can override config options by providing command line arguments. :cipher - specify a cipher to use; :priv_path - path to priv directory; :prefix - prefix to use (defaults to default ); :password - use a password that's different from the one that's configured.","ref":"Mix.Tasks.Scr.Edit.html","title":"Mix.Tasks.Scr.Edit","type":"task"},{"doc":"Creates a new secret in the specified environment and under the specified name. It uses configuration of the current application to retrieve the keys and so on. Usage $ mix scr.insert prod database_password &quot;My Super Secret Password&quot; Config override You can override config options by providing command line arguments. :cipher - specify a cipher to use; :priv_path - path to priv directory; :prefix - prefix to use (defaults to default ); :password - use a password that's different from the one that's configured.","ref":"Mix.Tasks.Scr.Insert.html","title":"Mix.Tasks.Scr.Insert","type":"task"},{"doc":"Shows an existing secret in the specified environment and under the specified name. If the name of a secret is not provided, it lists all the existing secrets. It uses configuration of the current application to retrieve the keys and so on. Usage To show the secret use $ mix scr.show prod database_url If you want to list all the available secrets for the environment, you can run $ mix scr.show prod Config override You can override config options by providing command line arguments. :cipher - specify a cipher to use; :priv_path - path to priv directory; :prefix - prefix to use (defaults to default ); :password - use a password that's different from the one that's configured.","ref":"Mix.Tasks.Scr.Show.html","title":"Mix.Tasks.Scr.Show","type":"task"},{"doc":"Provides an interface to implement encryption methods. See SecretVault.Cipher.ErlangCrypto implementation for more details.","ref":"SecretVault.Cipher.html","title":"SecretVault.Cipher","type":"behaviour"},{"doc":"Decrypt the cypher_text with the key used to get it. If key is invalid, :invalid_key error is returned. If inappropriate text is passed as cypher_text , Cipher.Error is raised.","ref":"SecretVault.Cipher.html#c:decrypt/3","title":"SecretVault.Cipher.decrypt/3","type":"callback"},{"doc":"Encrypt the plain_text with the key .","ref":"SecretVault.Cipher.html#c:encrypt/3","title":"SecretVault.Cipher.encrypt/3","type":"callback"},{"doc":"Serialize encryption metadata end a ciphertext into a single binary. This is a helper function to prepare the data to be written on the disk. Example iex&gt; cipher = &quot;MyNewCipher&quot; ...&gt; algorithm = &quot;default&quot; ...&gt; ciphertext = &quot;testtest&quot; ...&gt; pack ( cipher , algorithm , [ ciphertext ] ) &quot;MyNewCipher;default;7465737474657374&quot;","ref":"SecretVault.Cipher.html#pack/3","title":"SecretVault.Cipher.pack/3","type":"function"},{"doc":"Deserialize pack/3 'ed data. Example iex&gt; cipher = &quot;MyNewCipher&quot; iex&gt; serialized = &quot;MyNewCipher;default;7465737474657374&quot; iex&gt; unpack! ( cipher , serialized ) [ &quot;default&quot; , &quot;testtest&quot; ]","ref":"SecretVault.Cipher.html#unpack!/2","title":"SecretVault.Cipher.unpack!/2","type":"function"},{"doc":"Binary blob that contains encrypted data.","ref":"SecretVault.Cipher.html#t:cypher_text/0","title":"SecretVault.Cipher.cypher_text/0","type":"type"},{"doc":"A key for symetric encryption algorithm as a binary.","ref":"SecretVault.Cipher.html#t:key/0","title":"SecretVault.Cipher.key/0","type":"type"},{"doc":"Binary blob that contains decrypted data.","ref":"SecretVault.Cipher.html#t:plain_text/0","title":"SecretVault.Cipher.plain_text/0","type":"type"},{"doc":"SecretVault.Cipher implementation which uses :crypto module. It is enabled by default and it the recommended cipher to use. As for now it uses :aes_256_gcm mode as default and the only available cipher.","ref":"SecretVault.Cipher.ErlangCrypto.html","title":"SecretVault.Cipher.ErlangCrypto","type":"module"},{"doc":"Stores passwords in plaintext. Implements SecretVault.Cipher . Warning This cipher is insecure and it is supposed to be used only in testing or in self encrypting filesystems.","ref":"SecretVault.Cipher.Plaintext.html","title":"SecretVault.Cipher.Plaintext","type":"module"},{"doc":"PKCS #2 PBKDF2 (Password-Based Key Derivation Function 2). Implements SecretVault.KeyDerivation .","ref":"SecretVault.KDFs.PBKDF2.html","title":"SecretVault.KDFs.PBKDF2","type":"module"},{"doc":"Call the PBKDF function. Options :key_length - set the key length (default is 32); :iterations_count - set the count of iterations (default is 5).","ref":"SecretVault.KDFs.PBKDF2.html#kdf/2","title":"SecretVault.KDFs.PBKDF2.kdf/2","type":"function"},{"doc":"","ref":"SecretVault.KDFs.PBKDF2.html#t:option/0","title":"SecretVault.KDFs.PBKDF2.option/0","type":"type"},{"doc":"Defines an interface to derive a key from user-defined password.","ref":"SecretVault.KeyDerivation.html","title":"SecretVault.KeyDerivation","type":"behaviour"},{"doc":"Return binary derived from user_input .","ref":"SecretVault.KeyDerivation.html#c:kdf/2","title":"SecretVault.KeyDerivation.kdf/2","type":"callback"},{"doc":"This exception gets raised when some error occurs during decoding of an encrypted secret.","ref":"SecretVault.Cipher.Error.html","title":"SecretVault.Cipher.Error","type":"exception"},{"doc":"Exception for bang functions in SecretVault .","ref":"SecretVault.Error.html","title":"SecretVault.Error","type":"exception"},{"doc":"All-in-one solution for storing your Elixir application secrets inside the repository.","ref":"readme.html","title":"SecretVault 🔒","type":"extras"},{"doc":"Standalone . No dependencies on external binaries. Secure . Uses aes256gcm cipher by default. Detects weak and similar passwords with mix scr.audit task. Developer friendly . You can use mix scr.* tasks to create or edit secrets in your favourit editor. Or you can use simple coreutils like mv , rm , cp . Easy to use . Documatation is rich, errors are descriptive and tutorials take no more than 5 minutes to read. VCS friendly . SecretVault stores secrets in separate files, thus makes it easily to track in VCS. Mix friendly . SecretVault enforces separation of secrets for different environments. Extensible . You can connect your own ciphers, vaults or key derivation functions. OTP Compatible . Uses modern OTP 24 key derivation functions, or fallbacks to elixir implementation on lower OTP versions.","ref":"readme.html#features","title":"SecretVault 🔒 - Features","type":"extras"},{"doc":"Check out this 5 minutes usage tutorial for basics and useful links.","ref":"readme.html#usage","title":"SecretVault 🔒 - Usage","type":"extras"},{"doc":"Just add it to the list of dependencies like def deps do [ { :secret_vault , &quot;~&gt; 1.0&quot; } ] end","ref":"readme.html#installation","title":"SecretVault 🔒 - Installation","type":"extras"},{"doc":"If you want to contribute to the project or just want to test it localy (not as a dependency), you'll need to create config/config.exs file with following content. config :secret_vault , :secret_vault , default : [ password : &quot;Some super secret&quot; ] Thanks @benonymus -- for battle testing the project and giving the idea for runtime_secret macro","ref":"readme.html#hacking","title":"SecretVault 🔒 - Hacking","type":"extras"},{"doc":"1.0.1 Fixes the bug with wrong env detected in fetch_from_current_env 1.0.0 initial version","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"This is a 6 minutes SecretVault tutorial that shows how to install and configure SecretVault for umbrella applications.","ref":"umbrella.html","title":"Umbrella tutorial","type":"extras"},{"doc":"Create a separate dummy application in your apps directory like $ cd apps $ mix new secret_store $ cd secret_store Remove lib and test directories and chagne README.md to reflect that this application is used solely for secret management $ rm -rf lib test $ mkdir priv $ echo &quot;# SecretStore\\n\\nDummy storage for secrets&quot; &gt; README.md","ref":"umbrella.html#setup","title":"Umbrella tutorial - Setup","type":"extras"},{"doc":"Just add it into your SecretStore 's dependencies like defp deps do [ { :secret_vault , &quot;~&gt; 1.0&quot; } ] end","ref":"umbrella.html#install","title":"Umbrella tutorial - Install","type":"extras"},{"doc":"Configuration is straightforward. Minimal configuration would look like this: import Config config :secret_store , :secret_vault , default : [ password : System . fetch_env! ( &quot;SECRET_VAULT_PASSWORD&quot; ) ] # Here `default` is a name of a default prefix. Prefixes work like namespaces for secrets. You can provide options other than password . To see a full list of those check out the SecretVault.Config.new/2 documentation. Note Each MIX_ENV will have it's own separate vault, so don't use prefixes to separate envs.","ref":"umbrella.html#configure","title":"Umbrella tutorial - Configure","type":"extras"},{"doc":"To create a secret during development, you can use one of many secret creating tasks available. But do not forget to provide the enviroment variable with the password which we specified above. For example (inside apps/secret_store ), $ export SECRET_VAULT_PASSWORD=&quot;password&quot; # Don&#39;t forget to change the password value $ mix scr.insert dev database_password &quot;My Super Secret Password&quot; Or, to be able to write a password in your favourite editor, use $ mix scr.create dev database_password Here dev defines the MIX_ENV for which you'd like to create a secret. And database_password is a name of the secret. These exact commands will create a secret in priv/dev/default/database_password.vault_secret . Each secret is written onto it's own file in vault directory in priv . This plays nice with version control systems and simplifies the user interface. Note Each secret is written into it's own file with .vault_secret extension. Therefore, secrets' names must be suitable file names.","ref":"umbrella.html#create-secrets","title":"Umbrella tutorial - Create secrets","type":"extras"},{"doc":"To edit already created secrets, one can use mix scr.insert and mix scr.edit commands. To delete, rename or copy secrets, one can use regular coreutils like mv , cp , rm , since each secret is placed under the corresponding directory in priv . Usually the path is priv/$MIX_ENV/$PREFIX/${SECRET_NAME}.vault_secret . For example, to delete secret which was created in previous step, one could write: $ rm priv/dev/default/database_password.vault_secret Or to rename a secret: $ cd priv/dev/default/ $ mv database_password.vault_secret db_password.vault_secret","ref":"umbrella.html#manipulate-secrets","title":"Umbrella tutorial - Manipulate secrets","type":"extras"},{"doc":"To access and use secrets from Elixir application, one first need to retrieve the vault configuration. Then, it is recommended to place the secrets into some runtime storage (like persistent_term , for example). So, regular workflow would look like defmodule MyApp.Application do use Application def start ( _type , _args ) do ... { :ok , config } = SecretVault.Config . fetch_from_current_env ( :my_app ) SecretVault.Storage . to_persistent_term ( config ) end end This will create config from configuration of your application and put all decrypted passwords in the persistent_term . See SecretVault.Config and SecretVault.Storage for more options. If you want to have you options in application env you can specify this in config.exs # in config/config.exs import Config config :secret_store , :secret_vault , default : [ password : System . fetch_env! ( &quot;SECRET_VAULT_PASSWORD&quot; ) ] # in application.ex start function { :ok , config } = SecretVault.Config . fetch_from_current_env ( :my_app ) SecretVault.Storage . to_application_env ( config )","ref":"umbrella.html#access-secrets","title":"Umbrella tutorial - Access secrets","type":"extras"},{"doc":"It is a common practice to configure application in configuration scripts like config/config.exs , config/dev.exs and config/runtime.exs . And there are two things a developer must keep in mind while working with them First of all, you must not use compile time configuration scritps (basically everything except runtime.exs ) for setting values from secrets, since these values will appear in app.src file in your _build or release ebin directory. Usually, this is not something you can tolerate Second, runtime.exs config will be called during initialization of your project and the enviroment of the project will be inherited from the enviroment which was during project compilation. This means, that for release created with MIX_ENV=dev mix release and called with MIX_ENV=prod myapp start , secrets (and all other configuration) will be fetched from dev enviroment. So, to configure secrets in runtime, you can write something like: # in config/runtime.exs import Config import SecretVault , only : [ runtime_secret! : 2 ] config :secret_store , MyApp.Repo , password : runtime_secret! ( :secret_store , &quot;database_password&quot; )","ref":"umbrella.html#runtime-configuration","title":"Umbrella tutorial - Runtime configuration","type":"extras"},{"doc":"There is no special behaviour for releases. Just mix release and use. Don't forget to add mix scr.audit task in your CI to enforce quality of passwords.","ref":"umbrella.html#release","title":"Umbrella tutorial - Release","type":"extras"},{"doc":"This is a 5 minutes SecretVault tutorial that shows how to install and configure SecretVault , and then create, delete, edit, and access secrets in runtime.","ref":"usage.html","title":"Usage tutorial","type":"extras"},{"doc":"Just add it into your dependencies like defp deps do [ { :secret_vault , &quot;~&gt; 1.0&quot; } ] end","ref":"usage.html#install","title":"Usage tutorial - Install","type":"extras"},{"doc":"Just create a priv directory in the root of your project","ref":"usage.html#create-priv-dir","title":"Usage tutorial - Create priv dir","type":"extras"},{"doc":"Configuration is straightforward. Minimal configuration would look like this: import Config config :my_app , :secret_vault , default : [ password : System . fetch_env! ( &quot;SECRET_VAULT_PASSWORD&quot; ) ] # Here `default` is a name of a default prefix. Prefixes work like namespaces for secrets. You can provide options other than password . To see a full list of those check out the SecretVault.Config.new/2 documentation. Note Each MIX_ENV will have it's own separate vault, so don't use prefixes to separate envs.","ref":"usage.html#configure","title":"Usage tutorial - Configure","type":"extras"},{"doc":"To create a secret during development, you can use one of many secret creating tasks available. But do not forget to provide the enviroment variable with the password which we specified above. For example, $ export SECRET_VAULT_PASSWORD=&quot;password&quot; # Don&#39;t forget to change the password value $ mix scr.insert dev database_password &quot;My Super Secret Password&quot; Or, to be able to write a password in your favourite editor, use $ mix scr.create dev database_password Here dev defines the MIX_ENV for which you'd like to create a secret. And database_password is a name of the secret. These exact commands will create a secret in priv/dev/default/database_password.vault_secret . Each secret is written onto it's own file in vault directory in priv . This plays nice with version control systems and simplifies the user interface. Note Each secret is written into it's own file with .vault_secret extension. Therefore, secrets' names must be suitable file names.","ref":"usage.html#create-secrets","title":"Usage tutorial - Create secrets","type":"extras"},{"doc":"To edit already created secrets, one can use mix scr.insert and mix scr.edit commands. To delete, rename or copy secrets, one can use regular coreutils like mv , cp , rm , since each secret is placed under the corresponding directory in priv . Usually the path is priv/$MIX_ENV/$PREFIX/${SECRET_NAME}.vault_secret . For example, to delete secret which was created in previous step, one could write: $ rm priv/dev/default/database_password.vault_secret Or to rename a secret: $ cd priv/dev/default/ $ mv database_password.vault_secret db_password.vault_secret","ref":"usage.html#manipulate-secrets","title":"Usage tutorial - Manipulate secrets","type":"extras"},{"doc":"To access and use secrets from Elixir application, one first need to retrieve the vault configuration. Then, it is recommended to place the secrets into some runtime storage (like persistent_term , for example). So, regular workflow would look like defmodule MyApp.Application do use Application def start ( _type , _args ) do ... { :ok , config } = SecretVault.Config . fetch_from_current_env ( :my_app ) SecretVault.Storage . to_persistent_term ( config ) end end This will create config from configuration of your application and put all decrypted passwords in the persistent_term . See SecretVault.Config and SecretVault.Storage for more options. If you want to have you options in application env you can specify this in config.exs # in config/config.exs import Config config :my_app , :secret_vault , default : [ password : System . fetch_env! ( &quot;SECRET_VAULT_PASSWORD&quot; ) ] # in application.ex start function { :ok , config } = SecretVault.Config . fetch_from_current_env ( :my_app ) SecretVault.Storage . to_application_env ( config )","ref":"usage.html#access-secrets","title":"Usage tutorial - Access secrets","type":"extras"},{"doc":"It is a common practice to configure application in configuration scripts like config/config.exs , config/dev.exs and config/runtime.exs . And there are two things a developer must keep in mind while working with them First of all, you must not use compile time configuration scritps (basically everything except runtime.exs ) for setting values from secrets, since these values will appear in app.src file in your _build or release ebin directory. Usually, this is not something you can tolerate Second, runtime.exs config will be called during initialization of your project and the enviroment of the project will be inherited from the enviroment which was during project compilation. This means, that for release created with MIX_ENV=dev mix release and called with MIX_ENV=prod myapp start , secrets (and all other configuration) will be fetched from dev enviroment. So, to configure secrets in runtime, you can write something like: # in config/runtime.exs import Config import SecretVault , only : [ runtime_secret! : 2 ] config :playground , MyApp.Repo , password : runtime_secret! ( :playground , &quot;database_password&quot; )","ref":"usage.html#runtime-configuration","title":"Usage tutorial - Runtime configuration","type":"extras"},{"doc":"There is no special behaviour for releases. Just mix release and use. Don't forget to add mix scr.audit task in your CI to enforce quality of passwords.","ref":"usage.html#release","title":"Usage tutorial - Release","type":"extras"}]